package net.wanji.com.cache;

import lombok.extern.slf4j.Slf4j;
import net.wanji.com.service.controller.BeanMarkService;
import net.wanji.com.service.controller.ControlCommandService;
import net.wanji.com.service.controller.SignalStatusService;
import net.wanji.com.service.controller.StaticInfoService;
import net.wanji.com.common.enums.SignalInterfaceTypeEnum;
import net.wanji.common.framework.spring.ServiceBeanContext;
import org.springframework.boot.CommandLineRunner;
import org.springframework.stereotype.Component;

import java.util.HashMap;
import java.util.Map;

/**
 * @author duanruiming
 * @date 2023/05/08 11:05
 */
@Slf4j
@Component
public class SignalCommandInterfaceCache implements CommandLineRunner {

    private final Map<String, BeanMarkService> controlCommandInterfaceMap = new HashMap<>();

    /**
     * 获取缓存
     * key：主题名/类名，value: bean
     *
     * @return
     */
    public Map<String, BeanMarkService> getCache() throws Exception{
        if (controlCommandInterfaceMap.isEmpty()) {
            throw new Exception("SignalCommandInterfaceCache");
        }
        return controlCommandInterfaceMap;
    }

    @Override
    public void run(String... args) throws Exception {
        Map<String, BeanMarkService> map = ServiceBeanContext.getInterfaceBeanMap(BeanMarkService.class);
        for (Map.Entry<String, BeanMarkService> item : map.entrySet()) {
            BeanMarkService bean = item.getValue();
            String beanMark = bean.getBeanMark();
            String type = "";
            if (bean instanceof ControlCommandService) {
                type = SignalInterfaceTypeEnum.CONTROL.getCode();
            }
            if (bean instanceof SignalStatusService) {
                type = SignalInterfaceTypeEnum.STATUS.getCode();
            }
            if (bean instanceof StaticInfoService) {
                type = SignalInterfaceTypeEnum.STATIC.getCode();
            }
            controlCommandInterfaceMap.put(beanMark.concat(type), bean);

        }
    }

    /**
     * 通过beanMark获取接口实现类
     *
     * @param beanMark
     * @return
     */
    public BeanMarkService getService(String beanMark) {
        if (!controlCommandInterfaceMap.isEmpty()) {
            return controlCommandInterfaceMap.get(beanMark);
        }
        return null;
    }
}
