package net.wanji.com.controller;

/**
 * @author Kent HAN
 * @date 2022/12/1 15:07
 */

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.RequiredArgsConstructor;
import net.wanji.com.service.controller.SignalStatusService;
import net.wanji.common.annotation.aspect.AspectLog;
import net.wanji.common.enums.BaseEnum;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.databus.po.SignalStatusLogPO;
import net.wanji.databus.vo.LightsStatusVO;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.ws.rs.core.MediaType;
import java.util.List;

/**
 * 运行状态、告警、灯态信息接口
 *
 * @date 2022/11/15 9:38
 */
@Api(value = "运行状态、告警、灯态信息接口", tags = "运行状态、告警、灯态信息接口")
@RequestMapping("/signalStatus")
@RestController
@RequiredArgsConstructor
public class SignalStatusController {
    private final SignalStatusService signalStatusService;

    @AspectLog(description = "运行状态、告警数据", operationType = BaseEnum.OperationTypeEnum.QUERY)
    @PostMapping(value = "/runningStatusAlarm", produces = MediaType.APPLICATION_JSON)
    @ApiOperation(value = "运行状态、告警数据", notes = "运行状态、告警数据", response = SignalStatusLogPO.class,
            produces = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = SignalStatusLogPO.class)
    })
    public JsonViewObject runningStatusAlarm() {
        List<SignalStatusLogPO> signalStatusLogPOList = signalStatusService.runningStatusAlarm();
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        return jsonViewObject.success(signalStatusLogPOList);

    }

    @AspectLog(description = "灯态数据", operationType = BaseEnum.OperationTypeEnum.QUERY)
    @PostMapping(value = "/lightStatus", produces = MediaType.APPLICATION_JSON)
    @ApiOperation(value = "灯态数据", notes = "灯态数据", response = LightsStatusVO.class,
            produces = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = LightsStatusVO.class)
    })
    public JsonViewObject lightStatus() {
        List<LightsStatusVO> lightsStatusVOList = signalStatusService.lightStatus();
        JsonViewObject jsonViewObject = JsonViewObject.newInstance();
        return jsonViewObject.success(lightsStatusVOList);
    }
}
