package net.wanji.com.netty.handler;

import cn.hutool.core.util.HexUtil;
import io.netty.buffer.ByteBuf;
import io.netty.channel.ChannelHandlerContext;
import io.netty.channel.SimpleChannelInboundHandler;
import io.netty.channel.socket.DatagramPacket;
import lombok.extern.slf4j.Slf4j;
import net.wanji.com.cache.CrossInfoCache;
import net.wanji.com.cache.netty.NettyMessageCache;
import net.wanji.com.netty.commandsign.CommandResultSign;
import net.wanji.com.netty.pojo.CommandPojo;
import net.wanji.com.netty.response.CommandResponseFactory;
import net.wanji.com.pojo.netty.MessageResultPojo;
import net.wanji.common.framework.spring.ServiceBeanContext;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.net.InetSocketAddress;
import java.util.Objects;

import static net.wanji.com.common.enums.CommandResultSign.getClassNameByHexSign;

@Slf4j
@Component
public class NettyServerHandler extends SimpleChannelInboundHandler<DatagramPacket> {

    @Autowired
    CrossInfoCache crossInfoCache;

    /**
     * 读取消息
     *
     * @param ctx
     * @param packet
     * @throws Exception
     */
    @Override
    protected void channelRead0(ChannelHandlerContext ctx, DatagramPacket packet) throws Exception {
        log.info("收到服务端包数据： {}", packet);
        ByteBuf content = packet.content();
        InetSocketAddress remote = packet.sender();
        int i = content.readableBytes();
        byte[] b = new byte[i];
        content.readBytes(b);
        String data = HexUtil.encodeHexStr(b);
        String hexSign = CommandResultSign.getHexSign(data);
        if (StringUtils.isEmpty(hexSign)) {
            log.error("返回命令标识为空hexSign: {}", hexSign);
            return;
        }
        String className = getClassNameByHexSign(hexSign);
        CommandResponseFactory commandResponseFactory = (CommandResponseFactory) ServiceBeanContext.getBean(className);
        String key = StringUtils.join("/", remote.getHostString(), ":", remote.getPort(), "/", hexSign);
        CommandPojo commandPojo = getCommandPojo(key, data);
        String hexResult = commandResponseFactory.getCommandResponse(commandPojo);
        if (Objects.nonNull(hexResult)) {
            setResultData(key, hexResult);
        }
    }

    private void setResultData(String key, String hexResult) {
        MessageResultPojo resultPojo = NettyMessageCache.NETTY_MESSAGE_RESULT_MAP.get(key);
        if (resultPojo != null) {
            resultPojo.setHexMessageResult(hexResult);
            resultPojo.getCountDownLatch().countDown();
        }
    }

    private CommandPojo getCommandPojo(String key, String data) {
//        CrossInfoPO crossInfo = crossInfoCache.getCrossInfo(key);
        CommandPojo commandPojo = new CommandPojo();
//        commandPojo.setCrossId(crossInfo.getId());
//        commandPojo.setSignalId(crossInfo.getCode());
//        commandPojo.setSignalIp(crossInfo.getIp());
//        commandPojo.setPort(crossInfo.getPort());
        commandPojo.setCrossId("1111");
        commandPojo.setSignalId("2222");
        commandPojo.setSignalIp("10.102.1.204");
        commandPojo.setPort(5050);
        commandPojo.setResponseMsg(data);
        return commandPojo;
    }

    @Override
    public void exceptionCaught(ChannelHandlerContext ctx, Throwable cause) throws Exception {
    }
}
